@@ -114,8 +114,8 @@ parseResolvConf(char *filename)
 
     f = fopen(filename, "r");
     if(f == NULL) {
-        do_log_error(L_ERROR, -errno, "DNS: couldn't open %s", filename);
-        goto done;
+        do_log_error(L_ERROR, errno, "DNS: couldn't open %s", filename);
+        return 0;
     }
 
     while(1) {
@@ -156,7 +156,6 @@ parseResolvConf(char *filename)
         break;
     }
 
- done:
     fclose(f);
     if(nameserver) {
         dnsNameServer = nameserver;
@@ -266,6 +265,12 @@ do_gethostbyname(char *origname,
     int done, rc;
 
     memset(&request, 0, sizeof(request));
+    request.name = NULL;
+    request.addr = NULL;
+    request.error_message = NULL;
+    request.count = count;
+    request.handler = handler;
+    request.data = data;
 
     if(n <= 0 || n > 131) {
         if(n <= 0) {
@@ -297,11 +302,6 @@ do_gethostbyname(char *origname,
     }
 
     request.name = name;
-    request.addr = NULL;
-    request.error_message = NULL;
-    request.count = count;
-    request.handler = handler;
-    request.data = data;
 
     object = findObject(OBJECT_DNS, name->string, name->length);
     if(object == NULL || objectMustRevalidate(object, NULL)) {
@@ -809,7 +809,7 @@ dnsTimeoutHandler(TimeEventHandlerPtr event)
         rc = sendQuery(query);
         if(rc < 0) {
             do_log(L_ERROR, "Couldn't send DNS query.\n");
-            if(rc != -EWOULDBLOCK || rc != -EAGAIN || rc != -ENOBUFS) {
+            if(rc != -EWOULDBLOCK && rc != -EAGAIN && rc != -ENOBUFS) {
                 abortObject(object, 501,
                             internAtom("Couldn't send DNS query"));
                 goto fail;
@@ -1003,7 +1003,7 @@ really_do_dns(AtomPtr name, ObjectPtr object)
     object->flags |= OBJECT_INPROGRESS;
     rc = sendQuery(query);
     if(rc < 0) {
-        if(rc != -EWOULDBLOCK || rc != -EAGAIN || rc != -ENOBUFS) {
+        if(rc != -EWOULDBLOCK && rc != -EAGAIN && rc != -ENOBUFS) {
             object->flags &= ~OBJECT_INPROGRESS;
             message = internAtomError(-rc, "Couldn't send DNS query");
             goto remove_fallback;
@@ -1378,7 +1378,7 @@ dnsBuildQuery(int id, char *buf, int offset, int n, AtomPtr name, int af)
     default: return EINVAL;
     }
 
-    if(i + 6 >= n) return -1;
+    if(i + 12 >= n) return -1;
     DO_HTONS(&buf[i], id); i += 2;
     DO_HTONS(&buf[i], 1<<8); i += 2;
     DO_HTONS(&buf[i], 1); i += 2;
