@@ -68,8 +68,7 @@ timeval_minus(struct timeval *d, struct timeval *s1, struct timeval *s2)
 int
 timeval_minus_usec(struct timeval *s1, struct timeval *s2)
 {
-    return (s1->tv_sec - s2->tv_sec) * 1000000 + 
-        s1->tv_usec - s2->tv_usec;
+    return (s1->tv_sec - s2->tv_sec) * 1000000 + s1->tv_usec - s2->tv_usec;
 }
 
 static void
@@ -299,11 +298,11 @@ allocateFdEventNum(int fd)
         new_poll_fds = realloc(poll_fds, new_size * sizeof(struct pollfd));
         if(!new_poll_fds)
             return -1;
-        new_fdEvents = realloc(fdEvents, new_size * sizeof(FdEventHandlerRec));
+        new_fdEvents = realloc(fdEvents, new_size * sizeof(FdEventHandlerPtr));
         if(!new_fdEvents)
             return -1;
         new_fdEventsLast = realloc(fdEventsLast, 
-                                   new_size * sizeof(FdEventHandlerRec));
+                                   new_size * sizeof(FdEventHandlerPtr));
         if(!new_fdEventsLast)
             return -1;
 
